==> unit-1.1.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTableFilters.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTableFilters<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Reset reset;
	public _50_1_1682861417 _50_1_1682861417;
	public ComboFilterTemplate type;
	public _51_1_1886557047 _51_1_1886557047;
	public DateRangeFilterTemplate deleteDate;

    public AbstractTrashTableFilters(B box) {
        super(box);
        id("trashTableFilters");
    }

    @Override
	public void init() {
		super.init();
		if (reset == null) reset = register(new Reset(box()).<Reset>id("a_380214026").owner(AbstractTrashTableFilters.this));
		if (_50_1_1682861417 == null) _50_1_1682861417 = register(new _50_1_1682861417(box()).<_50_1_1682861417>id("a970563538").owner(AbstractTrashTableFilters.this));
		if (_50_1_1682861417 != null) type = _50_1_1682861417.type;
		if (_51_1_1886557047 == null) _51_1_1886557047 = register(new _51_1_1886557047(box()).<_51_1_1886557047>id("a313474732").owner(AbstractTrashTableFilters.this));
		if (_51_1_1886557047 != null) deleteDate = _51_1_1886557047.deleteDate;
	}

    @Override
    public void remove() {
        super.remove();
	    if (reset != null) reset.unregister();
	    if (_50_1_1682861417 != null) _50_1_1682861417.unregister();
	    if (_51_1_1886557047 != null) _51_1_1886557047.unregister();
	}

	public class Reset extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

		public Reset(B box) {
			super(box);
			_title("Reset filters");
			_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
	}

	public class _50_1_1682861417 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate type;

		public _50_1_1682861417(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new ComboFilterTemplate((UnitBox)box()).id("a809574469"));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (type != null) type.unregister();
		}
	}

	public class _51_1_1886557047 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DateRangeFilterTemplate deleteDate;

		public _51_1_1886557047(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (deleteDate == null) deleteDate = register(new DateRangeFilterTemplate((UnitBox)box()).id("a2030191203"));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (deleteDate != null) deleteDate.unregister();
		}
	}
}

==> unit-2.1.8-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTrashTableFilters.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTrashTableFilters<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Reset reset;
	public _50_1_1682861417 _50_1_1682861417;
	public ComboFilterTemplate type;
	public _51_1_1886557047 _51_1_1886557047;
	public DateRangeFilterTemplate deleteDate;

	public AbstractTrashTableFilters(B box) {
		super(box);
		id("trashTableFilters");
	}

	@Override
	public void init() {
		super.init();
		if (reset == null) reset = register(new Reset(box()).<Reset>id("a_380214026").owner(AbstractTrashTableFilters.this));
		if (_50_1_1682861417 == null) _50_1_1682861417 = register(new _50_1_1682861417(box()).<_50_1_1682861417>id("a970563538").owner(AbstractTrashTableFilters.this));
		if (_50_1_1682861417 != null) type = _50_1_1682861417.type;
		if (_51_1_1886557047 == null) _51_1_1886557047 = register(new _51_1_1886557047(box()).<_51_1_1886557047>id("a313474732").owner(AbstractTrashTableFilters.this));
		if (_51_1_1886557047 != null) deleteDate = _51_1_1886557047.deleteDate;
	}

	@Override
	public void remove() {
		super.remove();
		if (reset != null) reset.unregister();
		if (_50_1_1682861417 != null) _50_1_1682861417.unregister();
		if (_51_1_1886557047 != null) _51_1_1886557047.unregister();
	}

	public class Reset extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, B>  {

		public Reset(B box) {
			super(box);
			_title("Reset filters");
			_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
			super.unregister();
		}
	}

	public class _50_1_1682861417 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ComboFilterTemplate type;

		public _50_1_1682861417(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = AbstractTrashTableFilters.this.type = register(new ComboFilterTemplate((UnitBox)box()).id("a809574469"));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (type != null) type.unregister();
		}
	}

	public class _51_1_1886557047 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DateRangeFilterTemplate deleteDate;

		public _51_1_1886557047(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (deleteDate == null) deleteDate = AbstractTrashTableFilters.this.deleteDate = register(new DateRangeFilterTemplate((UnitBox)box()).id("a2030191203"));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (deleteDate != null) deleteDate.unregister();
		}
	}
}
